PlopRotTemp
#######################

Get started:
----------------

To run PlopRotTemp you must use the next command on linux shell:

1. pip install ploprottemp or conda install -c nostrumbiodiscovery ploprottemp

2. $ /path/to/academic/schrodinger -m PlopRotTemp.main /path/to/mae/ligand

Test
-------------

- cd Examples
- e.g /opt/schrodinger2017-4/utilities/python /path/to/PlopRotTemp/main.py AS4_INIT.mae

